==> humhub-1.4.1.tar.gz: humhub-1.4.1/protected/humhub/modules/user/messages/de/profile.php <==
<?php
return array (
  '<b>This profile stream is still empty!</b>' => '<b>Dieser Profilstream ist noch leer!</b>',
  '<b>This profile stream is still empty</b><br>Be the first and post something...' => '<b>Dieser Profil-Stream ist noch leer</b><br />Sei der erste und schreibe etwas...…',
  '<b>Your profile stream is still empty</b><br>Get started and post something...' => '<strong>Dein Stream ist noch leer!</strong><br />Mache den Anfang und schreibe etwas...',
  '<strong>About</strong> this user' => '<strong>Über</strong> diesen Nutzer',
  '<strong>Modify</strong> your title image' => 'Titelbild <strong>bearbeiten</strong> ',
  '<strong>Profile</strong> menu' => '<strong>Profil</strong>-Menü',
  '<strong>Something</strong> went wrong' => 'Ein <strong>Fehler</strong> ist aufgetreten',
  'About' => 'Über mich',
  'Allow other selection' => 'Weitere Auswahl zulassen',
  'Birthday' => 'Geburtstag',
  'Birthday field options' => 'Geburtstagsfeld-Optionen',
  'Checkbox' => 'Kontrollkästchen',
  'Checkbox List' => 'Kontrollkästchen-Liste',
  'Checkbox field options' => 'Kontrollkästchenfeld-Optionen',
  'City' => 'Ort',
  'Close' => 'Schließen',
  'Comma separated country codes, e.g. DE,EN,AU' => 'Komma getrennte Ländercodes, z. B. DE,EN,AU',
  'Communication' => 'Kommunikation',
  'Country' => 'Land',
  'Created at' => 'Erstellt am',
  'Created by' => 'Erstellt durch',
  'Custom' => 'Benutzerdefiniert',
  'Date' => 'Datum',
  'Date(-time) field options' => 'Datums(-Uhrzeit)feld-Optionen',
  'Datetime' => 'Datum/Uhrzeit',
  'Default value' => 'Standardwert',
  'Description' => 'Beschreibung',
  'Edit account' => 'Benutzerkonto bearbeiten',
  'Editable' => 'Editierbar',
  'Facebook URL' => 'Facebook-URL',
  'Fax' => 'Fax',
  'Female' => 'Weiblich',
  'Field Type could not be changed!' => 'Feldtyp konnte nicht geändert werden!',
  'Fieldtype' => 'Feldtyp',
  'First name' => 'Vorname',
  'Flickr URL' => 'Flickr-URL',
  'Followers' => 'Follower',
  'Following' => 'Folgend',
  'Friends' => 'Freunde',
  'Gender' => 'Geschlecht',
  'General' => 'Allgemein',
  'Google+ URL' => 'Google+-URL',
  'Hide age per default' => 'Standardmäßig Alter verstecken',
  'Hide year in profile' => 'Jahr im Profil verbergen',
  'ID' => 'ID',
  'Internal Name' => 'Interner Name',
  'Internal name already in use!' => 'Der interne Name wird bereits verwendet!',
  'Internal name could not be changed!' => 'Der interne Name konnte nicht geändert werden!',
  'Invalid field type!' => 'Ungültiger Feldtyp!',
  'LDAP Attribute' => 'LDAP-Attribut',
  'Last name' => 'Nachname',
  'LinkedIn URL' => 'LinkedIn-URL',
  'MSN' => 'MSN',
  'Male' => 'Männlich',
  'Markdown' => 'Markdown',
  'Maximum length' => 'Maximallänge',
  'Maximum value' => 'Maximum',
  'Minimum length' => 'Minimallänge',
  'Minimum value' => 'Minimum',
  'Mobile' => 'Mobil',
  'Module' => 'Modul',
  'Must contain at least one character.' => 'Muss mindestens ein Zeichen enthalten.',
  'MySpace URL' => 'MySpace-URL',
  'Number' => 'Zahl',
  'Number field options' => 'Zahlenfeld-Optionen',
  'Ok' => 'Ok',
  'One option per line. Key=>Value Format (e.g. yes=>Yes)' => 'Eine Option pro Zeile. Schlüssel=>Wert-Format (z.B. yes=>Ja)',
  'Only alphanumeric characters allowed!' => 'Nur alphanumerische Zeichen erlaubt!',
  'Phone Private' => 'Telefon privat',
  'Phone Work' => 'Telefon beruflich',
  'Please select:' => 'Bitte wähle:',
  'Possible values' => 'Mögliche Werte',
  'Profile Field Category' => 'Profilfeld-Kategorie',
  'Regular Expression: Error message' => 'Regulärer Ausdruck: Fehlermeldung',
  'Regular Expression: Validator' => 'Regulärer Ausdruck: Validator',
  'Required' => 'Erforderlich',
  'Save' => 'Speichern',
  'Searchable' => 'Durchsuchbar',
  'Select List' => 'Auswahlliste',
  'Select field options' => 'Auswahlfeld-Optionen',
  'Show at registration' => 'Bei der Registrierung anzeigen',
  'Show date/time picker' => 'Zeige Datums/Zeit Picker',
  'Skype Nickname' => 'Skype-Name',
  'Social bookmarks' => 'Soziale Lesezeichen',
  'Sort order' => 'Sortierung',
  'Spaces' => 'Spaces',
  'State' => 'Bundesland/Kanton',
  'Stream' => 'Stream',
  'Street' => 'Straße',
  'Supported ISO3166 country codes' => 'Unterstützte ISO3166 Länder Codes',
  'Text' => 'Text',
  'Text Area' => 'Textbereich',
  'Text Field Options' => 'Textfeld-Optionen',
  'Text area field options' => 'Textbereichsfeld-Optionen',
  'This profile is no longer available!' => 'Dieses Profil ist nicht mehr verfügbar!',
  'This user account is not approved yet!' => 'Dieser Account wurde noch nicht freigeschaltet!',
  'This will add an additional input element for custom values' => 'Fügt ein weiteres Eingabeelement für individuelle Werte hinzu',
  'Title' => 'Titel',
  'Translation Category ID' => 'Übersetzungs-Kategorie-ID',
  'Twitter URL' => 'Twitter-URL',
  'Type Config' => 'Typ-Konfiguration',
  'Updated at' => 'Aktualisiert am',
  'Updated by' => 'Aktualisiert durch',
  'Url' => 'URL',
  'Validator' => 'Validator',
  'Vimeo URL' => 'Vimeo-URL',
  'Visible' => 'Sichtbar',
  'XMPP Jabber Address' => 'XMPP Jabber-Addresse',
  'Xing URL' => 'Xing-URL',
  'You need to login to view this user profile!' => 'Sie müssen sich anmelden, um das Profil zu sehen!',
  'YouTube URL' => 'YouTube URL',
  'Zip' => 'PLZ',
);

==> humhub-1.4.2.tar.gz: humhub-1.4.2/protected/humhub/modules/user/messages/de/profile.php <==
<?php
return array (
  '<b>This profile stream is still empty!</b>' => '<b>Dieser Profilstream ist noch leer!</b>',
  '<b>This profile stream is still empty</b><br>Be the first and post something...' => '<b>Dieser Profil-Stream ist noch leer</b><br />Sei der erste und schreibe etwas ...',
  '<b>Your profile stream is still empty</b><br>Get started and post something...' => '<strong>Dein Stream ist noch leer!</strong><br />Mache den Anfang und schreibe etwas ...',
  '<strong>About</strong> this user' => '<strong>Über</strong> diesen Nutzer',
  '<strong>Modify</strong> your title image' => 'Titelbild <strong>bearbeiten</strong>',
  '<strong>Profile</strong> menu' => '<strong>Profil</strong>-Menü',
  '<strong>Something</strong> went wrong' => 'Ein <strong>Fehler</strong> ist aufgetreten',
  'About' => 'Über mich',
  'Allow other selection' => 'Weitere Auswahl zulassen',
  'Birthday' => 'Geburtstag',
  'Birthday field options' => 'Geburtstagsfeld-Optionen',
  'Checkbox' => 'Kontrollkästchen',
  'Checkbox List' => 'Kontrollkästchen-Liste',
  'Checkbox field options' => 'Kontrollkästchenfeld-Optionen',
  'City' => 'Ort',
  'Close' => 'Schließen',
  'Comma separated country codes, e.g. DE,EN,AU' => 'Komma getrennte Ländercodes, z. B. DE,EN,AU',
  'Communication' => 'Kommunikation',
  'Country' => 'Land',
  'Created at' => 'Erstellt am',
  'Created by' => 'Erstellt durch',
  'Custom' => 'Divers',
  'Date' => 'Datum',
  'Date(-time) field options' => 'Datums(-Uhrzeit)feld-Optionen',
  'Datetime' => 'Datum/Uhrzeit',
  'Default value' => 'Standardwert',
  'Description' => 'Beschreibung',
  'Edit account' => 'Benutzerkonto bearbeiten',
  'Editable' => 'Editierbar',
  'Facebook URL' => 'Facebook-URL',
  'Fax' => 'Fax',
  'Female' => 'Weiblich',
  'Field Type could not be changed!' => 'Feldtyp konnte nicht geändert werden!',
  'Fieldtype' => 'Feldtyp',
  'First name' => 'Vorname',
  'Flickr URL' => 'Flickr-URL',
  'Followers' => 'Follower',
  'Following' => 'Folgend',
  'Friends' => 'Freunde',
  'Gender' => 'Geschlecht',
  'General' => 'Allgemein',
  'Google+ URL' => 'Google+-URL',
  'Hide age per default' => 'Standardmäßig Alter verstecken',
  'Hide year in profile' => 'Jahr im Profil verbergen',
  'ID' => 'ID',
  'Internal Name' => 'Interner Name',
  'Internal name already in use!' => 'Der interne Name wird bereits verwendet!',
  'Internal name could not be changed!' => 'Der interne Name konnte nicht geändert werden!',
  'Invalid field type!' => 'Ungültiger Feldtyp!',
  'LDAP Attribute' => 'LDAP-Attribut',
  'Last name' => 'Nachname',
  'LinkedIn URL' => 'LinkedIn-URL',
  'MSN' => 'MSN',
  'Male' => 'Männlich',
  'Markdown' => 'Markdown',
  'Maximum length' => 'Maximallänge',
  'Maximum value' => 'Maximum',
  'Minimum length' => 'Minimallänge',
  'Minimum value' => 'Minimum',
  'Mobile' => 'Mobil',
  'Module' => 'Modul',
  'Must contain at least one character.' => 'Muss mindestens ein Zeichen enthalten.',
  'MySpace URL' => 'MySpace-URL',
  'Number' => 'Zahl',
  'Number field options' => 'Zahlenfeld-Optionen',
  'Ok' => 'Ok',
  'One option per line. Key=>Value Format (e.g. yes=>Yes)' => 'Eine Option pro Zeile. Schlüssel=&gt;Wert-Format (z.B. yes=&gt;Ja)',
  'Only alphanumeric characters allowed!' => 'Nur alphanumerische Zeichen erlaubt!',
  'Phone Private' => 'Telefon privat',
  'Phone Work' => 'Telefon dienstlich',
  'Please select:' => 'Bitte wähle:',
  'Possible values' => 'Mögliche Werte',
  'Profile Field Category' => 'Profilfeld-Kategorie',
  'Regular Expression: Error message' => 'Regulärer Ausdruck: Fehlermeldung',
  'Regular Expression: Validator' => 'Regulärer Ausdruck: Validator',
  'Required' => 'Erforderlich',
  'Save' => 'Speichern',
  'Searchable' => 'Durchsuchbar',
  'Select List' => 'Auswahlliste',
  'Select field options' => 'Auswahlfeld-Optionen',
  'Show at registration' => 'Bei der Registrierung anzeigen',
  'Show date/time picker' => 'Zeige Datums/Zeit Picker',
  'Skype Nickname' => 'Skype-Name',
  'Social bookmarks' => 'Links',
  'Sort order' => 'Sortierung',
  'Spaces' => 'Spaces',
  'State' => 'Bundesland/Kanton',
  'Stream' => 'Stream',
  'Street' => 'Straße',
  'Supported ISO3166 country codes' => 'Unterstützte ISO3166 Länder Codes',
  'Text' => 'Text',
  'Text Area' => 'Textbereich',
  'Text Field Options' => 'Textfeld-Optionen',
  'Text area field options' => 'Textbereichsfeld-Optionen',
  'This profile is no longer available!' => 'Dieses Profil ist nicht mehr verfügbar!',
  'This user account is not approved yet!' => 'Dieser Account wurde noch nicht freigeschaltet!',
  'This will add an additional input element for custom values' => 'Fügt ein weiteres Eingabeelement für individuelle Werte hinzu',
  'Title' => 'Titel',
  'Translation Category ID' => 'Übersetzungs-Kategorie-ID',
  'Twitter URL' => 'Twitter-URL',
  'Type Config' => 'Typ-Konfiguration',
  'Updated at' => 'Aktualisiert am',
  'Updated by' => 'Aktualisiert durch',
  'Url' => 'URL',
  'Validator' => 'Validator',
  'Vimeo URL' => 'Vimeo-URL',
  'Visible' => 'Sichtbar',
  'XMPP Jabber Address' => 'XMPP Jabber-Addresse',
  'Xing URL' => 'XING-URL',
  'You need to login to view this user profile!' => 'Sie müssen sich anmelden, um das Profil zu sehen!',
  'YouTube URL' => 'YouTube-URL',
  'Zip' => 'PLZ',
);
